#!/bin/sh
# The next line restarts using nmrWish \
exec nmrWish "$0" -- "$@"

set auto_path   "[split $env(TCLPATH) :] $auto_path"
set ARGV        [concat $argv0 $argv]
set ARGC        [llength $ARGV]

#
#-----------------------------------------------------------

set inName  series.tab
set outName j.series.tab

set tau1    0.000
set tau2    0.050

set jMin     8.000
set jMax    15.000
set jStep    0.010

#
#-----------------------------------------------------------

set PI 3.14159265

gdbInit
gdbCreate dBase

set pkTab [gdbRead table -in $inName -name "Coupling Values"]

gdbCreate variable -parent $pkTab -name D -varType float -varFmt %8.3f

set entry [gdbFirst $pkTab]

while {$entry} \
   {
    set ass   [gdbGet $entry ASS]
    set a0    [gdbGet $entry A_A0]
    set a1    [gdbGet $entry A_A1]
    set ratio [expr $a1/$a0]

    set bestVal 1.0e+16
    set bestJ   9999.0
    set bestR   0.0

    set j       $jMin 

    while {$j <= $jMax} \
       {
        set top [expr cos( $PI*$j*$tau2 )]
        set bot [expr cos( $PI*$j*$tau1 )]

        if {abs($bot) > 0.000001} \
           {
            set d [expr $ratio - $top/$bot]
            set q [expr $d*$d]

            if {$q < $bestVal} \
               {
                set bestVal $q
                set bestJ   $j
                set bestR   [expr $top/$bot]
               }
           }

        set j [expr $j + $jStep]
       }

    set fmt "Ass: %4s A0: %.3f A1: %8.4f Ratio: % 8.4f R: % 8.4f J: %8.4f"
   
    puts [format $fmt $ass $a0 $a1 $ratio $bestR $bestJ]
 
    gdbSet $entry D $j

    set entry [gdbNext $entry]
   }

gdbWrite $pkTab $outName
exit
